@@ -2,34 +2,31 @@
 from time import time
 from time import sleep
 from bd_time import tt, vk, Time
+from pydamo_0.regsvr import RegDM, run_in_bat
+
+print('This is self_model')
 
 class DM:
     def __init__(self):
-        try:
-            from win32com.client import Dispatch
-            #dm = Dispatch('dm.dmsoft')  # 调用大漠插件
-            self.dm = Dispatch('dm.dmsoft')  # 调用大漠插件
+        # try:
+        #     from win32com.client import Dispatch
+        #     dm = Dispatch('dm.dmsoft')  # 调用大漠插件
+        #     self.reg_infos = 0
+        # except:
+        reg_dm = RegDM()
+        # reg_dm.unreg_dm()
+        dm = reg_dm.reg()
+        self.reg_infos = reg_dm
 
-        except:
-            print('调用dm.dll失败!')
-            import os, subprocess
-
-            try:
-                tt.tqdm_sleep('启用[方案1-regsvr32]自动注册中...')
-                os.system('regsvr32 dm.dll /s')
-                self.dm = Dispatch('dm.dmsoft')  # 调用大漠插件
-                print('自动注册dm.dll - os.system方案')
-            except:
-                try:
-                    tt.tqdm_sleep('启用[方案2-admin权限]自动注册中...')
-                    subprocess.call(cmd='regist_dm_admin.bat', shell=True)
-                    self.dm = Dispatch('dm.dmsoft')  # 调用大漠插件
-                    print('自动注册dm.dll - 管理员权限方案')
-                except:
-                    tt.MessageBox('自动注册大漠插件失败,请手动注册!')
-                    # print('注册大漠插件失败,请手动注册!')
-
-        print('版本：', self.ver(),'，ID：',self.GetID())
+        if(dm):
+            self.dm = dm
+            print('版本：', self.ver(),'，ID：',self.GetID())
+        else:
+            print('dm.dll注册失败!\n请检查python版本\n或手动注册dm.dll!')
+        1
+    def __repr__(self):
+        ret = '版本： ' + str(self.ver()) + '，ID：' + str(self.GetID())
+        return ret
 
     def reg(self, reg_code = 'albin7a7a6b9740b219fb4db62c7865e00437', ver_info = '123'):
         # print('reg: ', self.dm.Reg('albin7a7a6b9740b219fb4db62c7865e00437', '123'))
@@ -436,7 +433,7 @@ class DM:
         def ExitOs(self, type):
             return self.dm.ExitOs(type)
 
-        def Beep(self, duration=500, f=500):
+        def Beep(self, duration=1000, f=800):
             return self.dm.Beep(f, duration)
 
     # My function
@@ -547,8 +544,16 @@ class Mouse:
         else:
             self.dm = dm
 
+    @property
     def position(self):
-        return self.dm.GetCursorPos(x=0, y=0)[1:]
+        ret = self.dm.GetCursorPos(x=0, y=0)[1:]
+        return ret
+    @position.setter
+    def position(self, xy):
+        x, y = xy
+        self.move_to(x, y)
+        ret = x, y
+        return ret
 
     def set_delay(self, delay, type='dx'):
         return self.dm.SetMouseDelay(type, delay)
@@ -595,6 +600,9 @@ class Mouse:
 if __name__ == '__main__':
     dm = DM()
     print(dm.ver())
+    import os
+    os.system('regsvr32 dm.dll -u -s')
+
 
     if (0):
         # debug
